"use client";

import React, { useEffect, useState, Suspense } from "react";
import { useRouter, useSearchParams } from "next/navigation";
import Head from "next/head"; // Import Head for SEO
import AdSense from '@/app/components/AdSense';

const ProcessingStepTwoContent: React.FC = () => {
  const router = useRouter();
  const searchParams = useSearchParams();
  const [loading, setLoading] = useState(true);
  const [linksAvailable, setLinksAvailable] = useState(false);
  const [movieData, setMovieData] = useState<any>(null);
  const [countdown, setCountdown] = useState(9); // 9-second countdown
  const [isButtonEnabled, setIsButtonEnabled] = useState(false);

  const id = Number(searchParams.get("id")); // Convert movieId to a number
  const movieType = searchParams.get("type"); // This should be 'movie' or 'tv'
  const releaseYear = searchParams.get("year"); // Get the releaseYear from the URL

  useEffect(() => {
    if (!id || !movieType || !releaseYear) {
      router.push("/");
      return;
    }

    const fetchDownloadLinks = async () => {
      try {
        // Fetch the correct year's JSON file dynamically
        const response = await fetch(`/json/${releaseYear}.json`);
        const data = await response.json();

        const movieInfo = data.find(
          (item: any) => item.id === id && item.type === movieType
        );

        if (movieInfo) {
          setMovieData(movieInfo);
          setLinksAvailable(true);
        } else {
          setLinksAvailable(false);
        }
      } catch (error) {
        console.error("Error fetching download links:", error);
        setLinksAvailable(false);
      } finally {
        setLoading(false);
      }
    };

    fetchDownloadLinks();

    // Start countdown
    const interval = setInterval(() => {
      setCountdown((prevCountdown) => {
        if (prevCountdown === 1) {
          clearInterval(interval);
          setIsButtonEnabled(true); // Enable the button after countdown
        }
        return prevCountdown - 1;
      });
    }, 1000);

    return () => clearInterval(interval); // Cleanup interval on component unmount
  }, [id, movieType, releaseYear, router]);

  const handleContinue = () => {
    if (linksAvailable && movieData) {
      // Redirect to the final download page
      router.push(`/download?id=${movieData.id}&type=${movieType}&year=${releaseYear}`);
    } else {
      alert("No download links available. Please try again later.");
    }
  };

  const handleReport = () => {
    if (movieData) {
      const subject = encodeURIComponent(`Fix ${movieData.title}`);
      const body = encodeURIComponent(
        `Hello,\n\nThe download link for "${movieData.title}" is not working. Could you please fix it?\n\nThank you!`
      );
      window.location.href = `mailto:support@example.com?subject=${subject}&body=${body}`;
    }
  };

  const handleTelegramReport = () => {
    window.open("https://t.me/delgomoviesdiscussion", "_blank");
  };

  if (loading) {
    return (
      <div className="flex flex-col items-center justify-center h-screen">
        <p className="text-lg text-white">Processing... Please wait.</p>
      </div>
    );
  }

  const pageTitle = linksAvailable
    ? `Preparing Download Link for "${movieData?.title}" - Delgor`
    : `Download Link Not Found - Delgor`;

  const pageDescription = linksAvailable
    ? `The download link for "${movieData?.title}" is being prepared. Please wait a moment.`
    : `Sorry, we couldn't find the download link for "${movieData?.title || "this item"}". Please report the issue and we'll fix it soon.`;

  return (
    <>
      <Head>
        <title>{pageTitle}</title>
        <meta name="description" content={pageDescription} />
        <link rel="canonical" href={`https://www.delgor.com/processing-step-two?id=${id}&type=${movieType}&year=${releaseYear}`} />
        <meta property="og:title" content={pageTitle} />
        <meta property="og:description" content={pageDescription} />
        <meta property="og:type" content="website" />
        <meta property="og:url" content={`https://www.delgor.com/processing-step-two?id=${id}&type=${movieType}&year=${releaseYear}`} />
        <meta property="og:image" content="/images/og-image.jpg" /> {/* Replace with an appropriate OG image */}
        <meta property="og:image:alt" content={`${movieData?.title || "Movie"} Poster`} />
      </Head>

      <div className="flex flex-col items-center justify-center h-screen text-center">
        {/* AdSense Ad at the Top */}
        <div className="w-full my-4">
          <AdSense />
        </div>

        {linksAvailable ? (
          <>
            <p className="text-lg text-white mb-4">
              Preparing Download Link for "{movieData?.title}".
            </p>
            <button
              onClick={handleContinue}
              className={`px-6 py-2 rounded ${
                isButtonEnabled
                  ? "bg-green-500 hover:bg-green-600 text-white cursor-pointer"
                  : "bg-gray-500 text-gray-300 cursor-not-allowed"
              }`}
              disabled={!isButtonEnabled}
            >
              {isButtonEnabled
                ? "Proceed to Download😊"
                : `Please wait ${countdown} seconds😁`}
            </button>
          </>
        ) : (
          <>
            <div className="animate-shake text-6xl mb-4">
              <span role="img" aria-label="sad emoji">
                😢
              </span>
            </div>
            <p className="text-lg text-white mb-4">
              Sorry, we couldn't find the link for "{movieData?.title || "this item"}".<br />
              Please report the issue, and we'll get it fixed within a few hours.
            </p>
            <div className="space-y-4">
              <button
                onClick={handleReport}
                className="flex items-center justify-center px-4 py-2 bg-yellow-500 text-white rounded hover:bg-yellow-600"
              >
                Report via Email
              </button>
              <button
                onClick={handleTelegramReport}
                className="flex items-center justify-center px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600"
              >
                Report via Telegram
              </button>
            </div>
          </>
        )}

        {/* AdSense Ad at the Bottom */}
        <div className="w-full my-4">
          <AdSense />
        </div>
      </div>
    </>
  );
};

export default function ProcessingStepTwoWrapper() {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <ProcessingStepTwoContent />
    </Suspense>
  );
}
